@@ -1,19 +1,19 @@
-import { CommonModule } from "@angular/common";
-import { HttpClientModule } from "@angular/common/http";
-import { NgModule } from "@angular/core";
-import { PluginInboxClientComponent } from "./plugin-inbox-client.component";
-import { Routes } from "@angular/router";
-import { FormsModule } from "@angular/forms";
-import { NzIconModule } from "ng-zorro-antd/icon";
-import { RouterModule } from "@angular/router";
+import { CommonModule } from "@angular/common"
+import { HttpClientModule } from "@angular/common/http"
+import { NgModule } from "@angular/core"
+import { PluginInboxClientComponent } from "./plugin-inbox-client.component"
+import { Routes } from "@angular/router"
+import { FormsModule } from "@angular/forms"
+import { NzIconModule } from "ng-zorro-antd/icon"
+import { RouterModule } from "@angular/router"
 import {
     LoggedInGuard,
     LoggedOutGuard,
     ProfileService,
     UserService,
-} from "@peek/peek_core_user";
-import { ActivityListComponent } from "./activity-list/activity-list.component";
-import { TaskListComponent } from "./task-list/task-list.component";
+} from "@peek/peek_core_user"
+import { ActivityListComponent } from "./activity-list/activity-list.component"
+import { TaskListComponent } from "./task-list/task-list.component"
 
 export const pluginRoutes: Routes = [
     {
@@ -26,7 +26,7 @@ export const pluginRoutes: Routes = [
         component: PluginInboxClientComponent,
         canActivate: [LoggedInGuard],
     },
-];
+]
 
 @NgModule({
     imports: [
@@ -44,4 +44,5 @@ export const pluginRoutes: Routes = [
         ActivityListComponent,
     ],
 })
-export class PluginInboxClientModule {}
+export class PluginInboxClientModule {
+}
