@@ -1,9 +1,7 @@
 import logging
 
-from peek_plugin_inbox._private.PluginNames import inboxFilt, \
-    inboxActionProcessorName
-from peek_plugin_inbox._private.server.controller.MainController import \
-    MainController
+from peek_plugin_inbox._private.PluginNames import inboxFilt, inboxActionProcessorName
+from peek_plugin_inbox._private.server.controller.MainController import MainController
 from vortex.handler.TupleActionProcessor import TupleActionProcessor
 
 logger = logging.getLogger(__name__)
@@ -13,5 +11,6 @@ def makeTupleActionProcessorHandler(inboxProcessor: MainController):
     processor = TupleActionProcessor(
         tupleActionProcessorName=inboxActionProcessorName,
         additionalFilt=inboxFilt,
-        defaultDelegate=inboxProcessor)
+        defaultDelegate=inboxProcessor,
+    )
     return processor
